#[derive(Clone, Default, Debug)]
pub struct HeaderFooterDrawing {

}
